@@ -1,27 +1,41 @@
 # -*- coding: utf-8 -*-
+# 版权所有 2019 深圳米筐科技有限公司（下称“米筐科技”）
 #
-# Copyright 2017 Ricequant, Inc
+# 除非遵守当前许可，否则不得使用本软件。
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+#     * 非商业用途（非商业用途指个人出于非商业目的使用本软件，或者高校、研究所等非营利机构出于教育、科研等目的使用本软件）：
+#         遵守 Apache License 2.0（下称“Apache 2.0 许可”），
+#         您可以在以下位置获得 Apache 2.0 许可的副本：http://www.apache.org/licenses/LICENSE-2.0。
+#         除非法律有要求或以书面形式达成协议，否则本软件分发时需保持当前许可“原样”不变，且不得附加任何条件。
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+#     * 商业用途（商业用途指个人出于任何商业目的使用本软件，或者法人或其他组织出于任何目的使用本软件）：
+#         未经米筐科技授权，任何个人不得出于任何商业目的使用本软件（包括但不限于向第三方提供、销售、出租、出借、转让本软件、
+#         本软件的衍生产品、引用或借鉴了本软件功能或源代码的产品或服务），任何法人或其他组织不得出于任何目的使用本软件，
+#         否则米筐科技有权追究相应的知识产权侵权责任。
+#         在此前提下，对本软件的使用同样需要遵守 Apache 2.0 许可，Apache 2.0 许可与本许可冲突之处，以本许可为准。
+#         详细的授权流程，请联系 public@ricequant.com 获取。
 
-from ..events import EVENT, Event
-from ..utils import run_when_strategy_not_hold
-from ..utils.logger import user_system_log
-from ..utils.i18n import gettext as _
-from ..utils.exception import ModifyExceptionFromType
-from ..execution_context import ExecutionContext
-from ..const import EXECUTION_PHASE, EXC_TYPE
-from ..environment import Environment
+from functools import wraps
+
+from rqalpha.events import EVENT, Event
+from rqalpha.utils.logger import user_system_log
+from rqalpha.utils.i18n import gettext as _
+from rqalpha.utils.exception import ModifyExceptionFromType
+from rqalpha.execution_context import ExecutionContext
+from rqalpha.const import EXECUTION_PHASE, EXC_TYPE
+from rqalpha.environment import Environment
+
+
+def run_when_strategy_not_hold(func):
+    from rqalpha.utils.logger import system_log
+
+    def wrapper(*args, **kwargs):
+        if not Environment.get_instance().config.extra.is_hold:
+            return func(*args, **kwargs)
+        else:
+            system_log.debug(_(u"not run {}({}, {}) because strategy is hold").format(func, args, kwargs))
+
+    return wrapper
 
 
 class Strategy(object):
@@ -32,6 +46,7 @@ class Strategy(object):
         self._init = scope.get('init', None)
         self._handle_bar = scope.get('handle_bar', None)
         self._handle_tick = scope.get('handle_tick', None)
+        self._open_auction = scope.get("open_auction", None)
         func_before_trading = scope.get('before_trading', None)
         if func_before_trading is not None and func_before_trading.__code__.co_argcount > 1:
             self._before_trading = lambda context: func_before_trading(context, None)
@@ -48,25 +63,18 @@ class Strategy(object):
             event_bus.add_listener(EVENT.TICK, self.handle_tick)
         if self._after_trading is not None:
             event_bus.add_listener(EVENT.AFTER_TRADING, self.after_trading)
-
-        self._before_day_trading = scope.get('before_day_trading', None)
-        self._before_night_trading = scope.get('before_night_trading', None)
-        if self._before_day_trading is not None:
-            user_system_log.warn(_(u"[deprecated] before_day_trading is no longer used. use before_trading instead."))
-        if self._before_night_trading is not None:
-            user_system_log.warn(_(u"[deprecated] before_night_trading is no longer used. use before_trading instead."))
+        if self._open_auction is not None:
+            event_bus.add_listener(EVENT.OPEN_AUCTION, self.open_auction)
 
     @property
     def user_context(self):
         return self._user_context
 
     def init(self):
-        if not self._init:
-            return
-
-        with ExecutionContext(EXECUTION_PHASE.ON_INIT):
-            with ModifyExceptionFromType(EXC_TYPE.USER_EXC):
-                self._init(self._user_context)
+        if self._init:
+            with ExecutionContext(EXECUTION_PHASE.ON_INIT):
+                with ModifyExceptionFromType(EXC_TYPE.USER_EXC):
+                    self._init(self._user_context)
 
         Environment.get_instance().event_bus.publish_event(Event(EVENT.POST_USER_INIT))
 
@@ -83,6 +91,13 @@ class Strategy(object):
             with ModifyExceptionFromType(EXC_TYPE.USER_EXC):
                 self._handle_bar(self._user_context, bar_dict)
 
+    @run_when_strategy_not_hold
+    def open_auction(self, event):
+        bar_dict = event.bar_dict
+        with ExecutionContext(EXECUTION_PHASE.OPEN_AUCTION):
+            with ModifyExceptionFromType(EXC_TYPE.USER_EXC):
+                self._open_auction(self._user_context, bar_dict)
+
     @run_when_strategy_not_hold
     def handle_tick(self, event):
         tick = event.tick
@@ -95,3 +110,11 @@ class Strategy(object):
         with ExecutionContext(EXECUTION_PHASE.AFTER_TRADING):
             with ModifyExceptionFromType(EXC_TYPE.USER_EXC):
                 self._after_trading(self._user_context)
+
+    def wrap_user_event_handler(self, handler):
+        @wraps(handler)
+        def wrapped_handler(event):
+            with ExecutionContext(EXECUTION_PHASE.GLOBAL):
+                with ModifyExceptionFromType(EXC_TYPE.USER_EXC):
+                    return handler(self._user_context, event)
+        return wrapped_handler
