@@ -300,13 +300,14 @@ class GenerateDayBarTask(DayBarTask):
                 order_book_ids = self._order_book_ids[i:i + step]
                 df = rqdatac.get_price(order_book_ids, START_DATE, datetime.date.today(), '1d',
                                        adjust_type='none', fields=fields, expect_df=True)
-                df.reset_index(inplace=True)
-                df['datetime'] = [convert_date_to_int(d) for d in df['date']]
-                del df['date']
-                df.set_index(['order_book_id', 'datetime'], inplace=True)
-                df.sort_index(inplace=True)
-                for order_book_id in df.index.levels[0]:
-                    h5.create_dataset(order_book_id, data=df.loc[order_book_id].to_records(), **kwargs)
+                if not (df is None or df.empty):
+                    df.reset_index(inplace=True)
+                    df['datetime'] = [convert_date_to_int(d) for d in df['date']]
+                    del df['date']
+                    df.set_index(['order_book_id', 'datetime'], inplace=True)
+                    df.sort_index(inplace=True)
+                    for order_book_id in df.index.levels[0]:
+                        h5.create_dataset(order_book_id, data=df.loc[order_book_id].to_records(), **kwargs)
                 i += step
                 yield len(order_book_ids)
                 if i >= len(self._order_book_ids):
@@ -334,7 +335,6 @@ class UpdateDayBarTask(DayBarTask):
                     df['datetime'] = [convert_date_to_int(d) for d in df['date']]
                     del df['date']
                     df.set_index('datetime', inplace=True)
-
                     if order_book_id in h5:
                         data = np.array(
                             [tuple(i) for i in chain(h5[order_book_id][:], df.to_records())],
