@@ -85,7 +85,7 @@ def init_persist_helper(env, ucontext, executor, config):
     if isinstance(env.event_source, Persistable):
         persist_helper.register('event_source', env.event_source)
     persist_helper.register('portfolio', env.portfolio)
-    for name, module in six.iteritems(env.mod_dict):
+    for name, module in env.mod_dict.items():
         if isinstance(module, Persistable):
             persist_helper.register('mod_{}'.format(name), module)
     # broker will restore open orders from account
@@ -113,7 +113,6 @@ def init_rqdatac(rqdatac_uri):
     try:
         import rqdatac
     except ImportError:
-        system_log.info(_('rqdatac is not available, some apis will not function properly'))
         return
 
     try:
@@ -188,7 +187,7 @@ def run(config, source_code=None, user_funcs=None):
             user_strategy.init()
 
         if config.extra.context_vars:
-            for k, v in six.iteritems(config.extra.context_vars):
+            for k, v in config.extra.context_vars.items():
                 if isinstance(v, RqAttrDict):
                     v = v.__dict__
                 setattr(ucontext, k, v)
@@ -234,8 +233,8 @@ def run(config, source_code=None, user_funcs=None):
 
 def _exception_handler(e):
     user_system_log.exception(_(u"strategy execute exception"))
+    user_system_log.error(e.error)
     if not is_user_exc(e.error.exc_val):
-        system_log.exception(_(u"strategy execute exception"))
         return const.EXIT_CODE.EXIT_INTERNAL_ERROR
 
     return const.EXIT_CODE.EXIT_USER_ERROR
@@ -257,7 +256,7 @@ def enable_profiler(env, scope):
         if inspect.isfunction(obj):
             scope[name] = profile_deco(obj)
         if inspect.isclass(obj):
-            for key, val in six.iteritems(obj.__dict__):
+            for key, val in obj.__dict__.items():
                 if inspect.isfunction(val):
                     setattr(obj, key, profile_deco(val))
 
@@ -284,9 +283,5 @@ def set_loggers(config):
 
     user_log.level = logbook.DEBUG
 
-    if extra_config.log_level.upper() != "NONE":
-        user_log.disabled = extra_config.user_log_disabled
-        user_system_log.disabled = extra_config.user_system_log_disabled
-
     for logger_name, level in extra_config.logger:
         getattr(logger, logger_name).level = getattr(logbook, level.upper())
